@@ -23,6 +23,15 @@ test_that("ggplot object is returned", {
   expect_is(u, "ggplot")
 })
 
+test_that("no warnings are produced", {
+  expect_silent(p)
+  expect_silent(q)
+  expect_silent(r)
+  expect_silent(s)
+  expect_silent(t)
+  expect_silent(u)
+})
+
 test_that("correct data is used", {
   p_map_data <- us_map(regions = "counties")
   expect_identical(p$data, p_map_data)
@@ -45,66 +54,66 @@ test_that("correct data is used", {
 
 test_that("layer parameters are correct", {
   expect_is(p$layers[[1]], "ggproto")
-  expect_equal(deparse(p$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(p$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(p$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(p$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(p$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(p$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(p$layers[[1]]$aes_params$colour), "black")
   expect_equal(as.character(p$layers[[1]]$aes_params$fill), "red")
   expect_equal(p$layers[[1]]$aes_params$size, 0.4)
 
   expect_is(q$layers[[1]], "ggproto")
-  expect_equal(deparse(q$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(q$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(q$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(q$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(q$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(q$layers[[1]]$mapping$group), "~group")
   expect_equal(deparse(q$layers[[1]]$mapping$fill), "~map_df[, values]")
   expect_equal(as.character(q$layers[[1]]$aes_params$colour), "blue")
   expect_equal(q$layers[[1]]$aes_params$size, 0.4)
 
   expect_is(r$layers[[1]], "ggproto")
-  expect_equal(deparse(r$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(r$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(r$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(r$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(r$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(r$layers[[1]]$mapping$group), "~group")
   expect_equal(deparse(r$layers[[1]]$mapping$fill), "~map_df[, values]")
   expect_equal(as.character(r$layers[[1]]$aes_params$colour), "black")
   expect_equal(r$layers[[1]]$aes_params$size, 0.8)
 
   expect_is(s$layers[[1]], "ggproto")
-  expect_equal(deparse(s$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(s$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(s$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(s$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(s$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(s$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(s$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(s$layers[[1]]$aes_params$colour), "black")
   expect_equal(s$layers[[1]]$aes_params$size, 0.4)
   expect_is(s$layers[[2]], "ggproto")
-  expect_equal(deparse(s$layers[[2]]$mapping$x), "~centroid_labels$x")
-  expect_equal(deparse(s$layers[[2]]$mapping$y), "~centroid_labels$y")
-  expect_equal(deparse(s$layers[[2]]$mapping$label), "~centroid_labels$abbr")
+  expect_equal(deparse(s$layers[[2]]$mapping$x), "~x")
+  expect_equal(deparse(s$layers[[2]]$mapping$y), "~y")
+  expect_equal(deparse(s$layers[[2]]$mapping$label), "~abbr")
   expect_equal(as.character(s$layers[[2]]$aes_params$colour), "blue")
 
   expect_is(t$layers[[1]], "ggproto")
-  expect_equal(deparse(t$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(t$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(t$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(t$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(t$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(t$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(t$layers[[1]]$aes_params$fill), "yellow")
   expect_equal(as.character(t$layers[[1]]$aes_params$colour), "black")
   expect_equal(t$layers[[1]]$aes_params$size, 0.6)
   expect_is(t$layers[[2]], "ggproto")
-  expect_equal(deparse(t$layers[[2]]$mapping$x), "~centroid_labels$x")
-  expect_equal(deparse(t$layers[[2]]$mapping$y), "~centroid_labels$y")
+  expect_equal(deparse(t$layers[[2]]$mapping$x), "~x")
+  expect_equal(deparse(t$layers[[2]]$mapping$y), "~y")
   expect_equal(deparse(t$layers[[2]]$mapping$label),
-               "~sub(\" County\", \"\", centroid_labels$county)")
+               "~sub(\" County\", \"\", county)")
 
   expect_is(u$layers[[1]], "ggproto")
-  expect_equal(deparse(u$layers[[1]]$mapping$x), "~map_df$x")
-  expect_equal(deparse(u$layers[[1]]$mapping$y), "~map_df$y")
-  expect_equal(deparse(u$layers[[1]]$mapping$group), "~map_df$group")
+  expect_equal(deparse(u$layers[[1]]$mapping$x), "~x")
+  expect_equal(deparse(u$layers[[1]]$mapping$y), "~y")
+  expect_equal(deparse(u$layers[[1]]$mapping$group), "~group")
   expect_equal(as.character(u$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(u$layers[[1]]$aes_params$colour), "black")
   expect_equal(u$layers[[1]]$aes_params$size, 0.4)
   expect_is(u$layers[[2]], "ggproto")
-  expect_equal(deparse(u$layers[[2]]$mapping$x), "~centroid_labels$x")
-  expect_equal(deparse(u$layers[[2]]$mapping$y), "~centroid_labels$y")
-  expect_equal(deparse(u$layers[[2]]$mapping$label), "~centroid_labels$abbr")
+  expect_equal(deparse(u$layers[[2]]$mapping$x), "~x")
+  expect_equal(deparse(u$layers[[2]]$mapping$y), "~y")
+  expect_equal(deparse(u$layers[[2]]$mapping$label), "~abbr")
 })
 
 test_that("singular regions can be used", {
